pyawair Python Wrapper for uhooair.com Air Quality Sensors
=======================



This project is offered under and Apache2 license and is not supported officialy by uHoo.

For more information, please visit the project home page at `GITHub.com <https://github
.com/netmanchris/pyuhooair`_.


What's Changed:

0.0.1  Initial Posting to Pypi. Basic functionality and scaffolding. Lots of work to do.
